Skip to contents

Raw, unthinned occurrence records for Rusa unicolor (Sambar deer) in Thailand. Used to demonstrate the spatial clustering and environmental bias typical of SDM datasets.

Usage

occ_data_raw

Format

A data.frame with one row per occurrence and the columns:

species

Species name.

x

Longitude (decimal degrees).

y

Latitude (decimal degrees).

Example dataset shipped with the bean package.