Skip to contents

Draws one panel per environmental variable showing the kernel density estimate used to derive the suggested grid resolution. The bandwidth is marked as a horizontal scale bar at the bottom of each panel.

Usage

# S3 method for class 'bean_env_resolution'
plot(x, ...)

Arguments

x

A bean_env_resolution object.

...

Additional graphical parameters passed to plot().

Value

Invisibly returns NULL.