Output of prepare_bean applied to occ_data_raw using
the bundled environmental rasters. Missing coordinates and records outside
the raster extent have been removed, and environmental values have been
extracted and standardised.
Output of prepare_bean applied to occ_data_raw using
the bundled environmental rasters. Missing coordinates and records outside
the raster extent have been removed, and environmental values have been
extracted and standardised.